==> aspose_words_cloud-20.10.1.tar.gz: lib/src/models/classification_response.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="classification_response.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// This response should be returned by the service when handling:
/// PUT https://api.aspose.cloud/v4.0/words/classify.
class ClassificationResponse extends WordsResponse {
  /// Gets or sets best class name.
  String bestClassName;

  /// Gets or sets best class probability.
  double bestClassProbability;

  /// Gets or sets array of best classes results.
  List<ClassificationResult> bestResults;

  @override
  void deserialize(Map<String, dynamic> json) {
    super.deserialize(json);
    if (json.containsKey('BestClassName')) {
      this.bestClassName = json['BestClassName'];
    } else {
      this.bestClassName = null;
    }

    if (json.containsKey('BestClassProbability')) {
      this.bestClassProbability = json['BestClassProbability'];
    } else {
      this.bestClassProbability = null;
    }

    if (json.containsKey('BestResults')) {
      // Array processing
      this.bestResults = new List<ClassificationResult>();
      for(final _element in json['BestResults']) {
        var _elementValue = new ClassificationResult();
        _elementValue.deserialize(_element);
        this.bestResults.add(_elementValue);
      }
    } else {
      this.bestResults = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = new Map<String, dynamic>();
    _result.addAll(super.serialize());
    if (this.bestClassName != null) {
      _result['BestClassName'] = this.bestClassName;
    }

    if (this.bestClassProbability != null) {
      _result['BestClassProbability'] = this.bestClassProbability;
    }

    if (this.bestResults != null) {
      _result['BestResults'] = this.bestResults.map((_element) => _element.serialize()).toList();
    }
    return _result;
  }
}

==> aspose_words_cloud-20.10.2.tar.gz: lib/src/models/classification_response.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="classification_response.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// This response should be returned by the service when handling:
/// PUT https://api.aspose.cloud/v4.0/words/classify.
class ClassificationResponse extends WordsResponse {
  /// Gets or sets best class name.
  String bestClassName;

  /// Gets or sets best class probability.
  double bestClassProbability;

  /// Gets or sets array of best classes results.
  List<ClassificationResult> bestResults;

  @override
  void deserialize(Map<String, dynamic> json) {
    super.deserialize(json);
    if (json.containsKey('BestClassName')) {
      bestClassName = json['BestClassName'];
    } else {
      bestClassName = null;
    }

    if (json.containsKey('BestClassProbability')) {
      bestClassProbability = json['BestClassProbability'];
    } else {
      bestClassProbability = null;
    }

    if (json.containsKey('BestResults')) {
      // Array processing
      bestResults = <ClassificationResult>[];
      for(final _element in json['BestResults']) {
        var _elementValue = ClassificationResult();
        _elementValue.deserialize(_element);
        bestResults.add(_elementValue);
      }
    } else {
      bestResults = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = <String, dynamic>{};
    _result.addAll(super.serialize());
    if (bestClassName != null) {
      _result['BestClassName'] = bestClassName;
    }

    if (bestClassProbability != null) {
      _result['BestClassProbability'] = bestClassProbability;
    }

    if (bestResults != null) {
      _result['BestResults'] = bestResults.map((_element) => _element.serialize()).toList();
    }
    return _result;
  }
}
